@@ -22,7 +22,7 @@ from textwrap import dedent
 import urllib3
 from hspylib.core.enums.charset import Charset
 from hspylib.core.tools.commons import syserr
-from hspylib.core.tools.zoned_datetime import now
+from hspylib.core.zoned_datetime import now
 from hspylib.modules.cli.application.application import Application
 from hspylib.modules.cli.application.version import Version
 
@@ -40,10 +40,10 @@ class Main(Application):
     DESCRIPTION = _Classpath.get_source_path("welcome.txt").read_text(encoding=str(Charset.UTF_8))
 
     # location of the .version file
-    VERSION_DIR = _Classpath.source_root()
+    VERSION_DIR = _Classpath.source_path()
 
     # The resources folder
-    RESOURCE_DIR = str(_Classpath.resource_dir())
+    RESOURCE_DIR = str(_Classpath.resource_path())
 
     def __init__(self, app_name: str):
         version = Version.load(load_dir=self.VERSION_DIR)
@@ -110,6 +110,8 @@ class Main(Application):
             syserr(f'### Unhandled operation: {op}')
             self.usage(1)
 
+    def _cleanup(self) -> None:
+        pass
 
 if __name__ == "__main__":
     # Application entry point
